#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.5.5
id: socks-0.5.5-0c45c80c2330de843f6569e694fbea7d
key: socks_0YMyCkcHxoaGiGc8lAEaV3
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (version 5) implementation.
description:
    Socks proxy (version 5) implementation.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/socks-0.5.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/socks-0.5.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/socks-0.5.5
hs-libraries: HSsocks-0.5.5-0YMyCkcHxoaGiGc8lAEaV3
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
